Index: webrtc/p2p/base/port.h |
diff --git a/webrtc/p2p/base/port.h b/webrtc/p2p/base/port.h |
index 2dc9deaddb311b89d6816c472265412444adf7b9..2acea42f68ff354f705e83466393304849441034 100644 |
--- a/webrtc/p2p/base/port.h |
+++ b/webrtc/p2p/base/port.h |
@@ -590,14 +590,11 @@ class Connection : public CandidatePairInterface, |
uint32_t ComputeNetworkCost() const; |
// Update the ICE password and/or generation of the remote candidate if a |
// ufrag in |remote_ice_parameters| matches the candidate's ufrag, and the |
// candidate's password and/or ufrag has not been set. |
- // |remote_ice_parameters| should be a list of known ICE parameters ordered |
- // by generation. |
- void MaybeSetRemoteIceCredentialsAndGeneration(const std::string& ice_ufrag, |
- const std::string& ice_pwd, |
- int generation); |
+ void MaybeSetRemoteIceParametersAndGeneration(const IceParameters& params, |
+ int generation); |
// If |remote_candidate_| is peer reflexive and is equivalent to |
// |new_candidate| except the type, update |remote_candidate_| to |
@@ -590,14 +590,11 @@ class Connection : public CandidatePairInterface, |
uint32_t ComputeNetworkCost() const; |
- // Update the ICE password and/or generation of the remote candidate if a |
- // ufrag in |remote_ice_parameters| matches the candidate's ufrag, and the |
+ // Update the ICE password and/or generation of the remote candidate if the |
+ // ufrag in |params| matches the candidate's ufrag, and the |
// candidate's password and/or ufrag has not been set. |